@@ -27,7 +27,9 @@
 #endif
 
 #include "core.h"
+#include "blist.h"
 #include "ui.h"
+#include "util.h"
 
 #define XPATCH BAD /* Because Kalla Said So */
 
@@ -155,14 +157,9 @@
 /*#define OPT_ACCT_KEEPALV	0x00000002 this shouldn't be optional */
 #define OPT_ACCT_REM_PASS	0x00000004
 #define OPT_ACCT_MAIL_CHECK      0x00000008
-/*do not use OPT_ACCT		0x00000010  talk to robot101 about automatic
- 						name stuff with this option
- */
 
 #define DEFAULT_INFO "Visit the Gaim website at <A HREF=\"http://gaim.sourceforge.net/\">http://gaim.sourceforge.net/</A>."
 
-
-
 enum log_event {
 	log_signon = 0,
 	log_signoff,
@@ -186,9 +183,6 @@ enum log_event {
 
 #define OPT_POUNCE_NOTIFY	0x200
 
-#define CONVERSATION_TITLE "%s - Gaim"
-#define LOG_CONVERSATION_TITLE "%s - Gaim (logged)"
-
 /* These should all be runtime selectable */
 
 #define MSG_LEN 2048
@@ -198,8 +192,7 @@ enum log_event {
 #define BUF_LEN MSG_LEN
 #define BUF_LONG BUF_LEN * 2
 
-/* Globals in aim.c */
-extern GList *buddy_pounces;
+/* Globals in main.c */
 extern int opt_away;
 extern char *opt_away_arg;
 extern char *opt_rcfile_arg;
@@ -208,9 +201,9 @@ extern int opt_debug;
 extern guint misc_options;
 #define OPT_MISC_DEBUG			0x00000001
 #define OPT_MISC_BROWSER_POPUP		0x00000002
-#define OPT_MISC_BUDDY_TICKER           0x00000004
-#define OPT_MISC_STEALTH_TYPING         0x00000010
-#define OPT_MISC_USE_SERVER_ALIAS		0x00000020
+#define OPT_MISC_BUDDY_TICKER		0x00000004
+#define OPT_MISC_STEALTH_TYPING		0x00000010
+#define OPT_MISC_USE_SERVER_ALIAS	0x00000020
 
 extern guint logging_options;
 #define OPT_LOG_CONVOS			0x00000001
@@ -230,12 +223,14 @@ extern guint blist_options;
 #define OPT_BLIST_SHOW_PIXMAPS		0x00000010
 #define OPT_BLIST_SHOW_IDLETIME		0x00000020
 #define OPT_BLIST_SHOW_BUTTON_XPM	0x00000040
-#define OPT_BLIST_NO_BUTTONS		0x00000080
+#define OPT_BLIST_NO_BUTTON_TEXT	0x00000080
 #define OPT_BLIST_NO_MT_GRP		0x00000100
 #define OPT_BLIST_SHOW_WARN		0x00000200
 #define OPT_BLIST_GREY_IDLERS		0x00000400
-#define OPT_BLIST_BOTTOM_TAB		0X00000800
+/* define OPT_BLIST_TOMBSTONE		0x00000800 */
 #define OPT_BLIST_POPUP                 0x00001000
+#define OPT_BLIST_SHOW_ICONS            0x00002000 
+#define OPT_BLIST_SHOW_OFFLINE          0x00004000
 
 extern guint convo_options;
 #define OPT_CONVO_ENTER_SENDS		0x00000001
@@ -314,9 +309,8 @@ extern guint sound_options;
 #define OPT_SOUND_CHAT_NICK             0x00040000
 
 extern guint away_options;
-#define OPT_AWAY_DISCARD		0x00000001
 #define OPT_AWAY_BACK_ON_IM		0x00000002
-/* #define OPT_AWAY_TIK_HACK		0x00000004 */
+/* #define OPT_AWAY_TOMBSTONE		0x00000004 */
 #define OPT_AWAY_AUTO			0x00000008
 #define OPT_AWAY_NO_AUTO_RESP		0x00000010
 #define OPT_AWAY_QUEUE			0x00000020
@@ -332,17 +326,15 @@ extern GSList *message_queue;
 extern GSList *unread_message_queue;
 extern GSList *away_time_queue;
 extern char web_command[2048];
+extern char sort_method[64];
 extern struct save_pos blist_pos;
 extern struct window_size conv_size, buddy_chat_size;
 
-/* Functions in aim.c */
+/* Functions in main.c */
 extern void do_quit();
 
-/* Functions in buddy.c */
+/* Functions in gtkblist.c */
 extern void signoff(struct gaim_connection *);
-extern void do_pounce(struct gaim_connection *, char *, int);
-void create_prpl_icon(GtkWidget *widget, struct gaim_connection *gc,
-					  GdkPixmap **pixmap, GdkBitmap **mask);
 
 /* Functions in buddy_chat.c */
 #if 0
@@ -354,19 +346,16 @@ extern void rename_chat_buddy(struct gaim_conversation *, char *, char *);
 extern void remove_chat_buddy(struct gaim_conversation *, char *, char *);
 #endif
 
-/* Functions in conversation.c */
-extern void set_anim();
-extern void set_blist_tab();
-
 /* Functions in dialogs.c */
-extern void g_show_info_text(struct gaim_connection *, char *, int, char *, ...);
-extern GtkWidget *do_error_dialog(const char *, const char *, int type);
+extern void g_show_info_text(struct gaim_connection *, const char *, int, const char *, ...);
 extern void show_change_passwd(struct gaim_connection *);
 extern void show_set_dir(struct gaim_connection *);
 extern void show_find_email(struct gaim_connection *);
 extern void show_find_info(struct gaim_connection *);
 extern void show_set_info(struct gaim_connection *);
 extern void show_confirm_del(struct gaim_connection *, gchar *);
+extern void show_confirm_del_group(struct group *);
+extern void show_confirm_del_chat(struct chat *);
 
 /* Functions in gaimrc.c */
 extern gint sort_awaymsg_list(gconstpointer, gconstpointer);
@@ -380,14 +369,12 @@ struct g_url {
 
 extern void grab_url(char *, gboolean, void (*callback)(gpointer, char *, unsigned long), gpointer);
 extern gchar *strip_html(const gchar *);
+extern void html_to_xhtml(const char *, char **, char **);
 struct g_url *parse_url(char *url);
 
 /* Functions in idle.c */
 extern gint check_idle(gpointer);
 
-/* Functions in prefs.c */
-extern void debug_printf(char * fmt, ...) G_GNUC_PRINTF(1,2);
-
 /* Functions in server.c */
 /* input to serv */
 extern void serv_login(struct gaim_account *);
@@ -414,48 +401,17 @@ extern void serv_set_permit_deny(struct gaim_connection *);
 extern void serv_warn(struct gaim_connection *, char *, int);
 extern void serv_set_dir(struct gaim_connection *, const char *, const char *, const char *, const char *, const char *, const char *, const char *, int);
 extern void serv_dir_search(struct gaim_connection *, const char *, const char *, const char *, const char *, const char *, const char *, const char *, const char *);
-extern void serv_join_chat(struct gaim_connection *, GList *);
+extern void serv_join_chat(struct gaim_connection *, GHashTable *);
 extern void serv_chat_invite(struct gaim_connection *, int, const char *, const char *);
 extern void serv_chat_leave(struct gaim_connection *, int);
 extern void serv_chat_whisper(struct gaim_connection *, int, char *, char *);
 extern int  serv_chat_send(struct gaim_connection *, int, char *);
 extern void serv_got_popup(char *, char *, int, int);
-extern void serv_get_away(struct gaim_connection *, char *);
+extern void serv_get_away(struct gaim_connection *, const char *);
 extern void serv_alias_buddy(struct buddy *);
 extern void serv_move_buddy(struct buddy *, struct group *, struct group *);
 extern void serv_rename_group(struct gaim_connection *, struct group *, const char *);
 
-/* Functions in util.c */
-extern char *normalize(const char *);
-extern char *tobase64(const char *);
-extern void frombase64(const char *, char **, int *);
-extern void clean_pid();
-extern char *date();
-extern gint linkify_text(char *);
-extern char *sec_to_text(guint);
-extern struct gaim_account *gaim_account_find(const char *, int) G_GNUC_PURE;
-extern char *full_date() G_GNUC_PURE;
-extern void check_gaim_versions();
-extern char *away_subs(char *, char *);
-extern char *stylize(gchar *, int);
-extern void show_usage (int, char *);
-extern const gchar *gaim_home_dir();
-extern char *gaim_user_dir();
-extern void strncpy_nohtml(gchar *, const gchar *, size_t);
-extern void strncpy_withhtml(gchar *, const gchar *, size_t);
-extern gchar *strdup_withhtml(const gchar *);
-extern void away_on_login(char *);
-extern char *add_cr(char *);
-extern void strip_linefeed(char *);
-extern time_t get_time(int, int, int, int, int, int) G_GNUC_CONST;
-extern FILE *gaim_mkstemp(gchar **);
-extern const char *handle_uri(char *);
-/* This guy does its best to convert a string to UTF-8 from an unknown
- * encoding by checking the locale and trying some sane defaults ...
- * if everything fails it returns NULL. */
-char *gaim_try_conv_to_utf8(const char *str);
-char *gaim_getip_from_fd(int fd);
-
 /* Functions in log.h */
 extern FILE *open_log_file (const char *, int);
 extern void system_log(enum log_event, struct gaim_connection *, struct buddy *, int);
