@@ -51,6 +51,11 @@
 
 #include <pango/pango-font.h>
 
+/* GTK+ < 2.2.2 hack, see ui.h for details. */
+#ifndef GTK_WRAP_WORD_CHAR
+#define GTK_WRAP_WORD_CHAR GTK_WRAP_WORD
+#endif
+
 #define TOOLTIP_TIMEOUT 500
 
 static gboolean gtk_motion_event_notify(GtkWidget *imhtml, GdkEventMotion *event, gpointer user_data);
@@ -66,7 +71,7 @@ static gint gtk_imhtml_tip (gpointer data);
 /* POINT_SIZE converts from AIM font sizes to point sizes.  It probably should be redone in such a
  * way that it base the sizes off the default font size rather than using arbitrary font sizes. */
 #define MAX_FONT_SIZE 7
-#define POINT_SIZE(x) (_point_sizes [MIN ((x), MAX_FONT_SIZE) - 1])
+#define POINT_SIZE(x) (options & GTK_IMHTML_USE_POINTSIZE ? x : _point_sizes [MIN ((x), MAX_FONT_SIZE) - 1])
 static gint _point_sizes [] = { 8, 10, 12, 14, 20, 30, 40 };
 
 /* The four elements present in a <FONT> tag contained in a struct */
@@ -207,7 +212,7 @@ static void gtk_imhtml_init (GtkIMHtml *imhtml)
 	gtk_text_buffer_get_end_iter (imhtml->text_buffer, &iter);
 	imhtml->end = gtk_text_buffer_create_mark(imhtml->text_buffer, NULL, &iter, FALSE);
 	gtk_text_view_set_buffer(GTK_TEXT_VIEW(imhtml), imhtml->text_buffer);
-	gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(imhtml), GTK_WRAP_WORD);
+	gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(imhtml), GTK_WRAP_WORD_CHAR);
 	gtk_text_view_set_editable(GTK_TEXT_VIEW(imhtml), FALSE);
 	gtk_text_view_set_pixels_below_lines(GTK_TEXT_VIEW(imhtml), 5);
 	gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(imhtml), FALSE);
@@ -292,12 +297,12 @@ static void url_open(GtkWidget *w, struct url_data *data) {
 static void url_copy(GtkWidget *w, gchar *url) {
 	GtkClipboard *clipboard;
 
-	clipboard = gtk_clipboard_get(GDK_SELECTION_CLIPBOARD);
+	clipboard = gtk_clipboard_get(GDK_SELECTION_PRIMARY);
 	gtk_clipboard_set_text(clipboard, url, -1);
 }
 
 /* The callback for an event on a link tag. */
-gboolean tag_event(GtkTextTag *tag, GObject *arg1, GdkEvent *event, GtkTextIter *arg2, char *url) {
+gboolean tag_event(GtkTextTag *tag, GObject *imhtml, GdkEvent *event, GtkTextIter *arg2, char *url) {
 	GdkEventButton *event_button = (GdkEventButton *) event;
 
 	if (event->type == GDK_BUTTON_RELEASE) {
@@ -312,14 +317,24 @@ gboolean tag_event(GtkTextTag *tag, GObject *arg1, GdkEvent *event, GtkTextIter
 
 			/* A link was clicked--we emit the "url_clicked" signal
 			 * with the URL as the argument */
-			g_signal_emit(arg1, signals[URL_CLICKED], 0, url);
+			g_signal_emit(imhtml, signals[URL_CLICKED], 0, url);
 			return FALSE;
 		} else if(event_button->button == 3) {
 			GtkWidget *img, *item, *menu;
 			struct url_data *tempdata = g_new(struct url_data, 1);
-			tempdata->object = g_object_ref(arg1);
+			tempdata->object = g_object_ref(imhtml);
 			tempdata->url = g_strdup(url);
 
+			/* Don't want the tooltip around if user right-clicked on link */
+			if (GTK_IMHTML(imhtml)->tip_window) {
+				gtk_widget_destroy(GTK_IMHTML(imhtml)->tip_window);
+				GTK_IMHTML(imhtml)->tip_window = NULL;
+			}
+			if (GTK_IMHTML(imhtml)->tip_timer) {
+				g_source_remove(GTK_IMHTML(imhtml)->tip_timer);
+				GTK_IMHTML(imhtml)->tip_timer = 0;
+			}
+			gdk_window_set_cursor(event_button->window, GTK_IMHTML(imhtml)->arrow_cursor);
 			menu = gtk_menu_new();
 
 			/* buttons and such */
@@ -622,6 +637,9 @@ gtk_imhtml_is_amp_escape (const gchar *string,
 	} else if (!g_ascii_strncasecmp (string, "&reg;", 5)) {
 		*replace = ''; /* was: '®' */
 		*length = 5;
+	} else if (!g_ascii_strncasecmp (string, "&apos;", 6)) {
+		*replace = '\'';
+		*length = 6;
 	} else if (*(string + 1) == '#') {
 		guint pound = 0;
 		if ((sscanf (string, "&#%u;", &pound) == 1) && pound != 0) {
@@ -693,7 +711,7 @@ gtk_imhtml_is_tag (const gchar *string,
 	VALID_TAG ("/HEAD");
 	VALID_TAG ("BINARY");
 	VALID_TAG ("/BINARY");
-	
+
 	VALID_OPT_TAG ("HR");
 	VALID_OPT_TAG ("FONT");
 	VALID_OPT_TAG ("BODY");
@@ -701,6 +719,18 @@ gtk_imhtml_is_tag (const gchar *string,
 	VALID_OPT_TAG ("IMG");
 	VALID_OPT_TAG ("P");
 	VALID_OPT_TAG ("H3");
+	VALID_OPT_TAG ("HTML");
+
+	VALID_TAG ("CITE");
+	VALID_TAG ("/CITE");
+	VALID_TAG ("EM");
+	VALID_TAG ("/EM");
+	VALID_TAG ("STRONG");
+	VALID_TAG ("/STRONG");
+
+	VALID_OPT_TAG ("SPAN");
+	VALID_TAG ("/SPAN");
+	VALID_TAG ("BR/"); /* hack until gtkimhtml handles things better */
 
 	if (!g_ascii_strncasecmp(string, "!--", strlen ("!--"))) {
 		gchar *e = strstr (string + strlen("!--"), "-->");
@@ -720,6 +750,10 @@ gtk_imhtml_get_html_opt (gchar       *tag,
 {
 	gchar *t = tag;
 	gchar *e, *a;
+	gchar *val;
+	gint len;
+	gchar c;
+	GString *ret;
 
 	while (g_ascii_strncasecmp (t, opt, strlen (opt))) {
 		gboolean quote = FALSE;
@@ -743,13 +777,30 @@ gtk_imhtml_get_html_opt (gchar       *tag,
 		while (*e && (*e != *(t - 1))) e++;
 		if  (*e == '\0') {
 			return NULL;
-		} else 
-			return g_strndup (a, e - a);
+		} else
+			val = g_strndup(a, e - a);
 	} else {
 		e = a = t;
 		while (*e && !isspace ((gint) *e)) e++;
-		return g_strndup (a, e - a);
+		val = g_strndup(a, e - a);
 	}
+
+	ret = g_string_new("");
+	e = val;
+	while(*e) {
+		if(gtk_imhtml_is_amp_escape(e, &c, &len)) {
+			ret = g_string_append_c(ret, c);
+			e += len;
+		} else {
+			ret = g_string_append_c(ret, *e);
+			e++;
+		}
+	}
+
+	g_free(val);
+	val = ret->str;
+	g_string_free(ret, FALSE);
+	return val;
 }
 
 
@@ -890,22 +941,26 @@ GString* gtk_imhtml_append_text (GtkIMHtml        *imhtml,
 				{
 				case 1:		/* B */
 				case 2:		/* BOLD */
+				case 54:	/* STRONG */
 					NEW_BIT (NEW_TEXT_BIT);
 					bold++;
 					break;
 				case 3:		/* /B */
 				case 4:		/* /BOLD */
+				case 55:	/* /STRONG */
 					NEW_BIT (NEW_TEXT_BIT);
 					if (bold)
 						bold--;
 					break;
 				case 5:		/* I */
 				case 6:		/* ITALIC */
+				case 52:	/* EM */
 					NEW_BIT (NEW_TEXT_BIT);
 					italics++;
 					break;
 				case 7:		/* /I */
 				case 8:		/* /ITALIC */
+				case 53:	/* /EM */
 					NEW_BIT (NEW_TEXT_BIT);
 					if (italics)
 						italics--;
@@ -973,6 +1028,7 @@ GString* gtk_imhtml_append_text (GtkIMHtml        *imhtml,
 					}
 					break;
 				case 25:	/* BR */
+				case 58:	/* BR/ */
 					ws[wpos] = '\n';
 					wpos++;
 					NEW_BIT (NEW_TEXT_BIT);
@@ -1160,8 +1216,13 @@ GString* gtk_imhtml_append_text (GtkIMHtml        *imhtml,
 					}
 				case 47:	/* P (opt) */
 				case 48:	/* H3 (opt) */
+				case 49:	/* HTML (opt) */
+				case 50:	/* CITE */
+				case 51:	/* /CITE */
+				case 56:	/* SPAN */
+				case 57:	/* /SPAN */
 					break;
-				case 49:	/* comment */
+				case 59:	/* comment */
 					NEW_BIT (NEW_TEXT_BIT);
 					if (imhtml->show_comments)
 						wpos = g_snprintf (ws, len, "%s", tag);
@@ -1307,9 +1368,25 @@ gtk_imhtml_clear (GtkIMHtml *imhtml)
 
 void gtk_imhtml_page_up (GtkIMHtml *imhtml)
 {
+	GdkRectangle rect;
+	GtkTextIter iter;
 
+	gtk_text_view_get_visible_rect(GTK_TEXT_VIEW(imhtml), &rect);
+	gtk_text_view_get_iter_at_location(GTK_TEXT_VIEW(imhtml), &iter, rect.x,
+									   rect.y - rect.height);
+	gtk_text_view_scroll_to_iter(GTK_TEXT_VIEW(imhtml), &iter, 0, TRUE, 0, 0);
+	
+}
+void gtk_imhtml_page_down (GtkIMHtml *imhtml)
+{
+	GdkRectangle rect;
+	GtkTextIter iter;
+
+	gtk_text_view_get_visible_rect(GTK_TEXT_VIEW(imhtml), &rect);
+	gtk_text_view_get_iter_at_location(GTK_TEXT_VIEW(imhtml), &iter, rect.x,
+									   rect.y + rect.height);
+	gtk_text_view_scroll_to_iter(GTK_TEXT_VIEW(imhtml), &iter, 0, TRUE, 0, 0);
 }
-void       gtk_imhtml_page_down        (GtkIMHtml        *imhtml){}
 
 static gint
 gtk_imhtml_tip_paint (GtkIMHtml *imhtml)
