@@ -56,12 +56,7 @@ extern char *yahoo_crypt(char *, char *);
 /* for win32 compatability */
 G_MODULE_IMPORT GSList *connections;
 
-#include "pixmaps/status-away.xpm"
-#include "pixmaps/status-here.xpm"
-#include "pixmaps/status-idle.xpm"
-#include "pixmaps/status-game.xpm"
-
-#define YAHOO_DEBUG
+/* #define YAHOO_DEBUG */
 
 #define USEROPT_MAIL 0
 
@@ -257,7 +252,8 @@ static void yahoo_packet_read(struct yahoo_packet *pkt, guchar *data, int len)
 			pair->value = g_strdup(value);
 			g_free(value);
 			pkt->hash = g_slist_append(pkt->hash, pair);
-			debug_printf("Key: %d  \tValue: %s\n", pair->key, pair->value);
+			gaim_debug(GAIM_DEBUG_MISC, "yahoo",
+					   "Key: %d  \tValue: %s\n", pair->key, pair->value);
 		} else {
 			g_free(pair);
 		}
@@ -297,24 +293,36 @@ static void yahoo_packet_dump(guchar *data, int len)
 {
 #ifdef YAHOO_DEBUG
 	int i;
+
+	gaim_debug(GAIM_DEBUG_MISC, "yahoo", "");
+
 	for (i = 0; i + 1 < len; i += 2) {
-		if ((i % 16 == 0) && i)
-			debug_printf("\n");
-		debug_printf("%02x", data[i]);
-		debug_printf("%02x ", data[i+1]);
+		if ((i % 16 == 0) && i) {
+			gaim_debug(GAIM_DEBUG_MISC, NULL, "\n");
+			gaim_debug(GAIM_DEBUG_MISC, "yahoo", "");
+		}
+
+		gaim_debug(GAIM_DEBUG_MISC, NULL, "%02x%02x ", data[i], data[i + 1]);
 	}
 	if (i < len)
-		debug_printf("%02x", data[i]);
-	debug_printf("\n");
+		gaim_debug(GAIM_DEBUG_MISC, NULL, "%02x", data[i]);
+
+	gaim_debug(GAIM_DEBUG_MISC, NULL, "\n");
+	gaim_debug(GAIM_DEBUG_MISC, "yahoo", "");
+
 	for (i = 0; i < len; i++) {
-		if ((i % 16 == 0) && i)
-			debug_printf("\n");
+		if ((i % 16 == 0) && i) {
+			gaim_debug(GAIM_DEBUG_MISC, NULL, "\n");
+			gaim_debug(GAIM_DEBUG_MISC, "yahoo", "");
+		}
+
 		if (isprint(data[i]))
-			debug_printf("%c ", data[i]);
+			gaim_debug(GAIM_DEBUG_MISC, NULL, "%c ", data[i]);
 		else
-			debug_printf(". ");
+			gaim_debug(GAIM_DEBUG_MISC, NULL, ". ");
 	}
-	debug_printf("\n");
+
+	gaim_debug(GAIM_DEBUG_MISC, NULL, "\n");
 #endif
 }
 
@@ -413,15 +421,11 @@ static void yahoo_process_status(struct gaim_connection *gc, struct yahoo_packet
 		case 13: /* in pager? */
 			if (pkt->service == YAHOO_SERVICE_LOGOFF ||
 			    strtol(pair->value, NULL, 10) == 0) {
-				serv_got_update(gc, name, 0, 0, 0, 0, 0, 0);
+				serv_got_update(gc, name, 0, 0, 0, 0, 0);
 				break;
 			}
 			if (g_hash_table_lookup(yd->games, name))
 				gamestate = YAHOO_STATUS_GAME;
-			if (state == YAHOO_STATUS_AVAILABLE)
-				serv_got_update(gc, name, 1, 0, 0, 0, gamestate, 0);
-			else 
-				serv_got_update(gc, name, 1, 0, 0, 0, (state << 2) | UC_UNAVAILABLE | gamestate, 0);
 			if (state == YAHOO_STATUS_CUSTOM) {
 				gpointer val = g_hash_table_lookup(yd->hash, name);
 				if (val) {
@@ -432,14 +436,21 @@ static void yahoo_process_status(struct gaim_connection *gc, struct yahoo_packet
 					g_hash_table_insert(yd->hash, g_strdup(name),
 							msg ? g_strdup(msg) : g_malloc0(1));
 			}
+			if (state == YAHOO_STATUS_AVAILABLE)
+				serv_got_update(gc, name, 1, 0, 0, 0, gamestate);
+			else if (state == YAHOO_STATUS_IDLE)
+				serv_got_update(gc, name, 1, 0, 0, -1, (state << 2) | UC_UNAVAILABLE | gamestate);
+			else
+				serv_got_update(gc, name, 1, 0, 0, 0, (state << 2) | UC_UNAVAILABLE | gamestate);
 			break;
 		case 60: /* no clue */
 			 break;
 		case 16: /* Custom error message */
-			do_error_dialog(pair->value, NULL, GAIM_ERROR);
+			gaim_notify_error(gc, NULL, pair->value, NULL);
 			break;
 		default:
-			debug_printf("unknown status key %d\n", pair->key);
+			gaim_debug(GAIM_DEBUG_ERROR, "yahoo",
+					   "Unknown status key %d\n", pair->key);
 			break;
 		}
 
@@ -451,6 +462,8 @@ static void yahoo_process_list(struct gaim_connection *gc, struct yahoo_packet *
 {
 	GSList *l = pkt->hash;
 	gboolean export = FALSE;
+	struct buddy *b;
+	struct group *g;
 
 	while (l) {
 		char **lines;
@@ -475,8 +488,13 @@ static void yahoo_process_list(struct gaim_connection *gc, struct yahoo_packet *
 			}
 			buddies = g_strsplit(split[1], ",", -1);
 			for (bud = buddies; bud && *bud; bud++)
-				if (!find_buddy(gc->account, *bud)) {
-					add_buddy(gc->account, split[0], *bud, *bud);
+				if (!(b = gaim_find_buddy(gc->account,  *bud))) {
+					if (!(g = gaim_find_group(split[0]))) {
+						g = gaim_group_new(split[0]);
+						gaim_blist_add_group(g, NULL);
+					}
+					b = gaim_buddy_new(gc->account, *bud, NULL);
+					gaim_blist_add_buddy(b, g, NULL);
 					export = TRUE;
 				}
 			g_strfreev(buddies);
@@ -513,16 +531,20 @@ static void yahoo_process_notify(struct gaim_connection *gc, struct yahoo_packet
 	if (!msg)
 		return;
 	
-	if (!g_strncasecmp(msg, "TYPING", strlen("TYPING"))) {
+	if (!g_ascii_strncasecmp(msg, "TYPING", strlen("TYPING"))) {
 		if (*stat == '1')
 			serv_got_typing(gc, from, 0, TYPING);
 		else
 			serv_got_typing_stopped(gc, from);
-	} else if (!g_strncasecmp(msg, "GAME", strlen("GAME"))) {
-		struct buddy *bud = find_buddy(gc->account, from);
+	} else if (!g_ascii_strncasecmp(msg, "GAME", strlen("GAME"))) {
+		struct buddy *bud = gaim_find_buddy(gc->account, from);
 		void *free1=NULL, *free2=NULL;
-		if (!bud)
-			debug_printf("%s is playing a game, and doesn't want you to know.\n", from);
+		if (!bud) {
+			gaim_debug(GAIM_DEBUG_WARNING, "yahoo",
+					   "%s is playing a game, and doesn't want "
+					   "you to know.\n", from);
+		}
+
 		if (*stat == '1') {
 			if (g_hash_table_lookup_extended (yd->games, from, free1, free2)) {
 				g_free(free1);
@@ -530,7 +552,7 @@ static void yahoo_process_notify(struct gaim_connection *gc, struct yahoo_packet
 			}
 			g_hash_table_insert (yd->games, g_strdup(from), g_strdup(game));
 			if (bud)
-				serv_got_update(gc, from, 1, 0, 0, 0, bud->uc | YAHOO_STATUS_GAME, 0);
+				serv_got_update(gc, from, 1, 0, 0, 0, bud->uc | YAHOO_STATUS_GAME);
 		} else {
 			if (g_hash_table_lookup_extended (yd->games, from, free1, free2)) {
 				g_free(free1);
@@ -538,7 +560,7 @@ static void yahoo_process_notify(struct gaim_connection *gc, struct yahoo_packet
 				g_hash_table_remove (yd->games, from);
 			}
 			if (bud)
-				serv_got_update(gc, from, 1, 0, 0, 0, bud->uc & ~YAHOO_STATUS_GAME, 0);
+				serv_got_update(gc, from, 1, 0, 0, 0, bud->uc & ~YAHOO_STATUS_GAME);
 		}
 	}
 }
@@ -579,7 +601,8 @@ static void yahoo_process_message(struct gaim_connection *gc, struct yahoo_packe
 		msg[j] = 0;
 		serv_got_im(gc, from, g_strdup(msg), 0, tm, -1);
 	} else if (pkt->status == 2) {
-		do_error_dialog(_("Your Yahoo! message did not get sent."), NULL, GAIM_ERROR);
+		gaim_notify_error(gc, NULL,
+						  _("Your Yahoo! message did not get sent."), NULL);
 	}
 }
 
@@ -604,7 +627,7 @@ static void yahoo_process_contact(struct gaim_connection *gc, struct yahoo_packe
 			who = pair->value;
 		else if (pair->key == 14)
 			msg = pair->value;
-		else if (pair->key == 7)
+		else if (pair->key == 7) 
 			name = pair->value;
 		else if (pair->key == 10)
 			state = strtol(pair->value, NULL, 10);
@@ -617,11 +640,11 @@ static void yahoo_process_contact(struct gaim_connection *gc, struct yahoo_packe
 		show_got_added(gc, id, who, NULL, msg);
 	if (name) {
 		if (state == YAHOO_STATUS_AVAILABLE)
-			serv_got_update(gc, name, 1, 0, 0, 0, 0, 0);
+			serv_got_update(gc, name, 1, 0, 0, 0, 0);
 		else if (state == YAHOO_STATUS_IDLE)
-			serv_got_update(gc, name, 1, 0, 0, time(NULL) - 600, (state << 2), 0);
+			serv_got_update(gc, name, 1, 0, 0, -1, (state << 2));
 		else
-			serv_got_update(gc, name, 1, 0, 0, 0, (state << 2) | UC_UNAVAILABLE, 0);
+			serv_got_update(gc, name, 1, 0, 0, 0, (state << 2) | UC_UNAVAILABLE);
 		if (state == YAHOO_STATUS_CUSTOM) {
 			gpointer val = g_hash_table_lookup(yd->hash, name);
 			if (val) {
@@ -643,6 +666,9 @@ static void yahoo_process_mail(struct gaim_connection *gc, struct yahoo_packet *
 	int count = 0;
 	GSList *l = pkt->hash;
 
+	if (!GAIM_ACCOUNT_CHECK_MAIL(gc->account))
+		return;
+
 	while (l) {
 		struct yahoo_pair *pair = l->data;
 		if (pair->key == 9)
@@ -658,10 +684,18 @@ static void yahoo_process_mail(struct gaim_connection *gc, struct yahoo_packet *
 
 	if (who && subj && email && *email) {
 		char *from = g_strdup_printf("%s (%s)", who, email);
-		connection_has_mail(gc, -1, from, subj, "http://mail.yahoo.com/");
+
+		gaim_notify_email(gc, subj, from, gc->username,
+						  "http://mail.yahoo.com/", NULL, NULL);
+
 		g_free(from);
-	} else if (count > 0)
-		connection_has_mail(gc, count, NULL, NULL, "http://mail.yahoo.com/");
+	} else if (count > 0) {
+		const char *to = gc->username;
+		const char *url = "http://mail.yahoo.com/";
+
+		gaim_notify_emails(gc, count, FALSE, NULL, NULL, &to, &url,
+						   NULL, NULL);
+	}
 }
 /* This is the y64 alphabet... it's like base64, but has a . and a _ */
 char base64digits[] = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789._";
@@ -855,7 +889,8 @@ static void yahoo_packet_process(struct gaim_connection *gc, struct yahoo_packet
 		yahoo_process_auth(gc, pkt);
 		break;
 	default:
-		debug_printf("unhandled service 0x%02x\n", pkt->service);
+		gaim_debug(GAIM_DEBUG_ERROR, "yahoo",
+				   "Unhandled service 0x%02x\n", pkt->service);
 		break;
 	}
 }
@@ -892,7 +927,8 @@ static void yahoo_pending(gpointer data, gint source, GaimInputCondition cond)
 		pos += 2;
 
 		pktlen = yahoo_get16(yd->rxqueue + pos); pos += 2;
-		debug_printf("%d bytes to read, rxlen is %d\n", pktlen, yd->rxlen);
+		gaim_debug(GAIM_DEBUG_MISC, "yahoo",
+				   "%d bytes to read, rxlen is %d\n", pktlen, yd->rxlen);
 
 		if (yd->rxlen < (YAHOO_PACKET_HDRLEN + pktlen))
 			return;
@@ -903,7 +939,9 @@ static void yahoo_pending(gpointer data, gint source, GaimInputCondition cond)
 
 		pkt->service = yahoo_get16(yd->rxqueue + pos); pos += 2;
 		pkt->status = yahoo_get32(yd->rxqueue + pos); pos += 4;
-		debug_printf("Yahoo Service: 0x%02x Status: %d\n", pkt->service, pkt->status);
+		gaim_debug(GAIM_DEBUG_MISC, "yahoo",
+				   "Yahoo Service: 0x%02x Status: %d\n",
+				   pkt->service, pkt->status);
 		pkt->id = yahoo_get32(yd->rxqueue + pos); pos += 4;
 
 		yahoo_packet_read(pkt, yd->rxqueue + pos, pktlen);
@@ -958,22 +996,24 @@ static void yahoo_login(struct gaim_account *account) {
 	struct gaim_connection *gc = new_gaim_conn(account);
 	struct yahoo_data *yd = gc->proto_data = g_new0(struct yahoo_data, 1);
 
-	set_login_progress(gc, 1, "Connecting");
+	set_login_progress(gc, 1, _("Connecting"));
 
 	yd->fd = -1;
 	yd->hash = g_hash_table_new(g_str_hash, g_str_equal);
 	yd->games = g_hash_table_new(g_str_hash, g_str_equal);
 
 
-	if (!g_strncasecmp(account->proto_opt[USEROPT_PAGERHOST], "cs.yahoo.com", strlen("cs.yahoo.com"))) {
+	if (!g_ascii_strncasecmp(account->proto_opt[USEROPT_PAGERHOST], "cs.yahoo.com", strlen("cs.yahoo.com"))) {
 		/* Figured out the new auth method -- cs.yahoo.com likes to disconnect on buddy remove and add now */
-		debug_printf("Setting new Yahoo! server.\n");
-		g_snprintf(account->proto_opt[USEROPT_PAGERHOST], strlen("scs.yahoo.com") + 1, "scs.yahoo.com");
+		gaim_debug(GAIM_DEBUG_INFO, "yahoo",
+				   "Setting new Yahoo! server.\n");
+		g_snprintf(account->proto_opt[USEROPT_PAGERHOST],
+				   strlen("scs.yahoo.com") + 1, "scs.yahoo.com");
 		save_prefs();
 	}
 
 
-	if (proxy_connect(account->proto_opt[USEROPT_PAGERHOST][0] ?
+	if (proxy_connect(account, account->proto_opt[USEROPT_PAGERHOST][0] ?
 				account->proto_opt[USEROPT_PAGERHOST] : YAHOO_PAGER_HOST,
 				account->proto_opt[USEROPT_PAGERPORT][0] ?
 				atoi(account->proto_opt[USEROPT_PAGERPORT]) : YAHOO_PAGER_PORT,
@@ -1009,15 +1049,28 @@ static void yahoo_close(struct gaim_connection *gc) {
 	g_free(yd);
 }
 
-static char **yahoo_list_icon(int uc)
+static const char *yahoo_list_icon(struct gaim_account *a, struct buddy *b)
 {
-	if ((uc >> 2) == YAHOO_STATUS_IDLE)
-		return status_idle_xpm;
-	else if (uc & UC_UNAVAILABLE)
-		return status_away_xpm;
-	else if (uc & YAHOO_STATUS_GAME)
-		return status_game_xpm;
-	return status_here_xpm;
+	return "yahoo";
+}
+
+static void yahoo_list_emblems(struct buddy *b, char **se, char **sw, char **nw, char **ne)
+{
+	int i = 0;
+	char *emblems[4] = {NULL,NULL,NULL,NULL};
+	if (b->present == GAIM_BUDDY_OFFLINE) {
+		*se = "offline";
+		return;
+	} else {
+		if (b->uc & UC_UNAVAILABLE)
+			emblems[i++] = "away";
+		if (b->uc & YAHOO_STATUS_GAME)
+			emblems[i++] = "game";
+	}
+	*se = emblems[0];
+	*sw = emblems[1];
+	*nw = emblems[2];
+	*ne = emblems[3];
 }
 
 static char *yahoo_get_status_string(enum yahoo_status a)
@@ -1043,12 +1096,14 @@ static char *yahoo_get_status_string(enum yahoo_status a)
 		return _("Stepped Out");
 	case YAHOO_STATUS_INVISIBLE:
 		return _("Invisible");
+	case YAHOO_STATUS_IDLE:
+		return _("Idle");
 	default:
 		return _("Online");
 	}
 }
 
-static void yahoo_game(struct gaim_connection *gc, char *name) {
+static void yahoo_game(struct gaim_connection *gc, const char *name) {
 	struct yahoo_data *yd = (struct yahoo_data *)gc->proto_data;
 	char *game = g_hash_table_lookup(yd->games, name);
 	char *t;
@@ -1064,30 +1119,55 @@ static void yahoo_game(struct gaim_connection *gc, char *name) {
 	open_url(NULL, url);
 	g_free(game);
 }
-static GList *yahoo_buddy_menu(struct gaim_connection *gc, char *who)
+
+static char *yahoo_status_text(struct buddy *b)
+{
+	struct yahoo_data *yd = (struct yahoo_data*)b->account->gc->proto_data;
+	if (b->uc & UC_UNAVAILABLE) {
+		if ((b->uc >> 2) != YAHOO_STATUS_CUSTOM)
+			return g_strdup(yahoo_get_status_string(b->uc >> 2));
+		else {
+			char *stripped = strip_html(g_hash_table_lookup(yd->hash, b->name));
+			if(stripped) {
+				char *ret = g_markup_escape_text(stripped, strlen(stripped));
+				g_free(stripped);
+				return ret;
+			}
+		}
+	}
+	return NULL;
+}
+
+static char *yahoo_tooltip_text(struct buddy *b)
+{
+	struct yahoo_data *yd = (struct yahoo_data*)b->account->gc->proto_data;
+	if (b->uc & UC_UNAVAILABLE) {
+		char *status;
+		char *ret;
+		if ((b->uc >> 2) != YAHOO_STATUS_CUSTOM)
+			status = g_strdup(yahoo_get_status_string(b->uc >> 2));
+		else
+			status = strip_html(g_hash_table_lookup(yd->hash, b->name));
+		if(status) {
+			char *escaped = g_markup_escape_text(status, strlen(status));
+			ret = g_strdup_printf(_("<b>Status:</b> %s"), escaped);
+			g_free(status);
+			g_free(escaped);
+			return ret;
+		}
+	}
+	return NULL;
+}
+
+static GList *yahoo_buddy_menu(struct gaim_connection *gc, const char *who)
 {
 	GList *m = NULL;
 	struct proto_buddy_menu *pbm;
 	struct yahoo_data *yd = (struct yahoo_data *)gc->proto_data;
-	struct buddy *b = find_buddy(gc->account, who); /* this should never be null. if it is,
+	struct buddy *b = gaim_find_buddy(gc->account, who); /* this should never be null. if it is,
 						  segfault and get the bug report. */
-	static char buf[1024];
 	static char buf2[1024];
-	
-	if (b->uc & UC_UNAVAILABLE && b->uc >> 2 != YAHOO_STATUS_IDLE) {
-		pbm = g_new0(struct proto_buddy_menu, 1);
-		if ((b->uc >> 2) != YAHOO_STATUS_CUSTOM)
-			g_snprintf(buf, sizeof buf, 
-				   "Status: %s", yahoo_get_status_string(b->uc >> 2));
-		else
-			g_snprintf(buf, sizeof buf, "Custom Status: %s",
-				   (char *)g_hash_table_lookup(yd->hash, b->name));
-		pbm->label = buf;
-		pbm->callback = NULL;
-		pbm->gc = gc;
-		m = g_list_append(m, pbm);
-	}
-	
+
 	if (b->uc | YAHOO_STATUS_GAME) {
 		char *game = g_hash_table_lookup(yd->games, b->name);
 		char *room;
@@ -1111,13 +1191,12 @@ static GList *yahoo_buddy_menu(struct gaim_connection *gc, char *who)
 			m = g_list_append(m, pbm);
 		}
 	}
-
+	
 	return m;
 }
 
-static void yahoo_act_id(gpointer data, char *entry)
+static void yahoo_act_id(struct gaim_connection *gc, const char *entry)
 {
-	struct gaim_connection *gc = data;
 	struct yahoo_data *yd = gc->proto_data;
 
 	struct yahoo_packet *pkt = yahoo_packet_new(YAHOO_SERVICE_IDACT, YAHOO_STATUS_AVAILABLE, 0);
@@ -1130,7 +1209,10 @@ static void yahoo_act_id(gpointer data, char *entry)
 
 static void yahoo_show_act_id(struct gaim_connection *gc)
 {
-	do_prompt_dialog("Activate which ID:", gc->displayname, gc, yahoo_act_id, NULL);
+	gaim_request_input(gc, NULL, _("Active which ID?"), NULL,
+					   gc->displayname, FALSE,
+					   _("OK"), G_CALLBACK(yahoo_act_id),
+					   _("Cancel"), NULL, gc);
 }
 
 static GList *yahoo_actions(struct gaim_connection *gc) {
@@ -1146,7 +1228,7 @@ static GList *yahoo_actions(struct gaim_connection *gc) {
 	return m;
 }
 
-static int yahoo_send_im(struct gaim_connection *gc, char *who, char *what, int len, int flags)
+static int yahoo_send_im(struct gaim_connection *gc, const char *who, const char *what, int len, int flags)
 {
 	struct yahoo_data *yd = gc->proto_data;
 	struct yahoo_packet *pkt = yahoo_packet_new(YAHOO_SERVICE_MESSAGE, YAHOO_STATUS_OFFLINE, 0);
@@ -1311,7 +1393,7 @@ static void yahoo_add_buddy(struct gaim_connection *gc, const char *who)
 	if (!yd->logged_in)
 		return;
 
-	g = find_group_by_buddy(find_buddy(gc->account, who));
+	g = gaim_find_buddys_group(gaim_find_buddy(gc->account, who));
 	if (g)
 		group = g->name;
 	else
@@ -1337,9 +1419,10 @@ static void yahoo_remove_buddy(struct gaim_connection *gc, char *who, char *grou
 	yahoo_packet_free(pkt);
 }
 
-static struct prpl *my_protocol = NULL;
+static GaimPlugin *my_protocol = NULL;
 
-G_MODULE_EXPORT void yahoo_init(struct prpl *ret) {
+#if 0
+G_MODULE_EXPORT void yahoo_init(GaimPlugin *ret) {
 	struct proto_user_opt *puo;
 	ret->protocol = PROTO_YAHOO;
 	ret->options = OPT_PROTO_MAIL_CHECK;
@@ -1348,6 +1431,9 @@ G_MODULE_EXPORT void yahoo_init(struct prpl *ret) {
 	ret->close = yahoo_close;
 	ret->buddy_menu = yahoo_buddy_menu;
 	ret->list_icon = yahoo_list_icon;
+	ret->list_emblems = yahoo_list_emblems;
+	ret->status_text = yahoo_status_text;
+	ret->tooltip_text = yahoo_tooltip_text;
 	ret->actions = yahoo_actions;
 	ret->send_im = yahoo_send_im;
 	ret->away_states = yahoo_away_states;
@@ -1382,3 +1468,107 @@ G_MODULE_EXPORT void gaim_prpl_init(struct prpl *prpl)
 }
 
 #endif
+#endif
+
+static GaimPluginProtocolInfo prpl_info =
+{
+	GAIM_PROTO_YAHOO,
+	OPT_PROTO_MAIL_CHECK | OPT_PROTO_USE_POINTSIZE,
+	NULL,
+	NULL,
+	yahoo_list_icon,
+	yahoo_list_emblems,
+	yahoo_status_text,
+	yahoo_tooltip_text,
+	yahoo_away_states,
+	yahoo_actions,
+	yahoo_buddy_menu,
+	NULL,
+	yahoo_login,
+	yahoo_close,
+	yahoo_send_im,
+	NULL,
+	yahoo_send_typing,
+	NULL,
+	yahoo_set_away,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	yahoo_set_idle,
+	NULL,
+	yahoo_add_buddy,
+	NULL,
+	yahoo_remove_buddy,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	yahoo_keepalive,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL
+};
+
+static GaimPluginInfo info =
+{
+	2,                                                /**< api_version    */
+	GAIM_PLUGIN_PROTOCOL,                             /**< type           */
+	NULL,                                             /**< ui_requirement */
+	0,                                                /**< flags          */
+	NULL,                                             /**< dependencies   */
+	GAIM_PRIORITY_DEFAULT,                            /**< priority       */
+
+	"prpl-yahoo",                                     /**< id             */
+	"Yahoo",	                                      /**< name           */
+	VERSION,                                          /**< version        */
+	                                                  /**  summary        */
+	N_("Yahoo Protocol Plugin"),
+	                                                  /**  description    */
+	N_("Yahoo Protocol Plugin"),
+	NULL,                                             /**< author         */
+	WEBSITE,                                          /**< homepage       */
+
+	NULL,                                             /**< load           */
+	NULL,                                             /**< unload         */
+	NULL,                                             /**< destroy        */
+
+	NULL,                                             /**< ui_info        */
+	&prpl_info                                        /**< extra_info     */
+};
+
+static void
+__init_plugin(GaimPlugin *plugin)
+{
+	struct proto_user_opt *puo;
+
+	puo = g_new0(struct proto_user_opt, 1);
+	puo->label = g_strdup("Pager Host:");
+	puo->def   = g_strdup(YAHOO_PAGER_HOST);
+	puo->pos   = USEROPT_PAGERHOST;
+	prpl_info.user_opts = g_list_append(prpl_info.user_opts, puo);
+
+	puo = g_new0(struct proto_user_opt, 1);
+	puo->label = g_strdup("Pager Port:");
+	puo->def   = g_strdup("5050");
+	puo->pos   = USEROPT_PAGERPORT;
+	prpl_info.user_opts = g_list_append(prpl_info.user_opts, puo);
+
+	my_protocol = plugin;
+}
+
+GAIM_INIT_PLUGIN(yahoo, __init_plugin, info);
