@@ -1,4 +1,7 @@
-/*
+/**
+ * @file ui.h Main GTK+ UI include file
+ * @defgroup gtkui GTK+ User Interface
+ *
  * gaim
  *
  * Copyright (C) 1998-1999, Mark Spencer <markster@marko.net>
@@ -16,7 +19,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
  */
 
 #ifndef _UI_H_
@@ -34,6 +36,7 @@
 #include "gtkconv.h"
 #include "pounce.h"
 #include "gtkft.h"
+#include "gtkprefs.h"
 #include "gtkutils.h"
 #include "stock.h"
 
@@ -41,6 +44,14 @@
 			gtk_window_set_type_hint(GTK_WINDOW(x), GDK_WINDOW_TYPE_HINT_DIALOG)
 #define GAIM_WINDOW_ICONIFIED(x) (gdk_window_get_state(GTK_WIDGET(x)->window) & GDK_WINDOW_STATE_ICONIFIED)
 
+/* This is backwards-compatibility code for old versions of GTK+ (2.2.1 and
+ * earlier).  It defines the new wrap behavior (unknown in earlier versions)
+ * as the old (slightly buggy) wrap behavior.
+ */
+#ifndef GTK_WRAP_WORD_CHAR
+#define GTK_WRAP_WORD_CHAR GTK_WRAP_WORD
+#endif
+
 #define DEFAULT_FONT_FACE "Helvetica"
 
 #define BROWSER_NETSCAPE              0
@@ -80,12 +91,6 @@ typedef enum {
 		GAIM_BUTTON_VERTICAL
 } GaimButtonStyle;
 
-
-struct debug_window {
-	GtkWidget *window;
-	GtkWidget *entry;
-};
-
 /* XXX CUI: save_pos and window_size are used by gaimrc.c which is core.
  * Need to figure out options saving. Same goes for several global variables as well. */
 struct save_pos {
@@ -167,12 +172,13 @@ extern GdkColor fgcolor;
 extern int smiley_array[FACE_TOTAL];
 extern GtkWidget *fgcseld;
 extern GtkWidget *bgcseld;
+void build_allow_list();
+void build_block_list();
 
 /* Globals in pounce.c */
 extern GtkWidget *bpmenu;
 
 /* Globals in prefs.c */
-extern GtkWidget *prefs;
 extern struct debug_window *dw;
 extern GtkWidget *fontseld;
 
@@ -228,30 +234,29 @@ extern void ui_add_group(struct group *);
 extern void ui_remove_group(struct group *);
 extern void toggle_buddy_pixmaps();
 extern void gaim_separator(GtkWidget *);
-extern void redo_buddy_list(); /* you really shouldn't call this function */
 extern void set_blist_tab();
 extern void hide_buddy_list();
 extern void unhide_buddy_list();
 extern void docklet_add();
 extern void docklet_remove();
 extern void docklet_toggle();
-extern GtkWidget *gaim_new_item(GtkWidget *, const char *);
 extern void update_idle_times();
 extern void build_imchat_box(gboolean);
 extern void show_xfer_dialog();
 
 /* Functions in dialogs.c */
 extern void alias_dialog_bud(struct buddy *);
+extern void alias_dialog_chat(struct chat *);
 extern void show_warn_dialog(struct gaim_connection *, char *);
 extern void show_im_dialog();
 extern void show_info_dialog();
 extern void show_add_buddy(struct gaim_connection *, char *, char *, char *);
+extern void show_add_chat(struct gaim_account *, struct group *);
 extern void show_add_group(struct gaim_connection *);
 extern void show_add_perm(struct gaim_connection *, char *, gboolean);
 extern void destroy_all_dialogs();
 extern void show_import_dialog();
 extern void show_export_dialog();
-extern void show_new_bp(char *, struct gaim_connection *, int, int, struct buddy_pounce *);
 extern void conv_show_log(GtkWidget *, gpointer);
 extern void chat_show_log(GtkWidget *, gpointer);
 extern void show_log(char *);
@@ -276,12 +281,9 @@ extern void set_color_selection(GtkWidget *selection, GdkColor color);
 extern void show_rename_group(GtkWidget *, struct group *);
 extern void show_rename_buddy(GtkWidget *, struct buddy *);
 extern void load_perl_script();
-extern GtkWidget *picture_button(GtkWidget *, char *, char **);
-extern GtkWidget *picture_button2(GtkWidget *, char *, char **, short);
 extern GtkWidget *gaim_pixbuf_button(char *, char *, GaimButtonStyle);
 extern GtkWidget *gaim_pixbuf_button_from_stock(const char *, const char *, GaimButtonStyle);
 extern GtkWidget *gaim_pixbuf_toolbar_button_from_stock(char *);
-extern GtkWidget *gaim_pixbuf_toolbar_button_from_file(char *);
 extern int file_is_dir(const char *, GtkWidget *);
 extern void update_privacy_connections();
 extern void show_privacy_options();
@@ -299,25 +301,6 @@ extern void show_plugins(GtkWidget *, gpointer);
 extern void update_show_plugins(); /* this is a hack and will be removed */
 #endif
 
-/* Functions in prefs.c */
-extern void set_option(GtkWidget *, int *);
-extern void show_prefs();
-extern void show_debug();
-extern void toggle_debug();
-extern void update_color(GtkWidget *, GtkWidget *);
-extern void set_default_away(GtkWidget *, gpointer);
-extern void default_away_menu_init(GtkWidget *);
-extern void build_allow_list();
-extern void build_block_list();
-extern GtkWidget *make_frame(GtkWidget *, char *);
-extern GtkListStore *prefs_away_store;
-extern GtkWidget *prefs_away_menu;
-extern GtkWidget *pref_fg_picture;
-extern GtkWidget *pref_bg_picture;
-extern void apply_font_dlg(GtkWidget *, GtkWidget *);
-extern void apply_color_dlg(GtkWidget *, gpointer);
-extern void destroy_colorsel(GtkWidget *, gpointer);
-
 /* Functions in prpl.c */
 extern void register_dialog();
 
@@ -335,12 +318,4 @@ extern void smiley_theme_probe();
 extern void load_smiley_theme(const char *file, gboolean load);
 extern GSList *get_proto_smileys(int protocol);
 
-/* Fucnctions in util.c */
-extern GtkWidget *gaim_pixmap(char *, char *);
-extern GdkPixbuf *gaim_pixbuf(char *, char *);
-extern GtkWidget *gaim_new_item(GtkWidget *menu, const char *str);
-extern GtkWidget *gaim_new_item_with_pixmap(GtkWidget *, const char *, char **, GtkSignalFunc, gpointer, guint, guint, char *);
-extern GtkWidget *gaim_new_item_from_stock(GtkWidget *, const char *, const char *, GtkSignalFunc, gpointer, guint, guint, char *);
-extern GtkWidget *gaim_new_item_from_pixbuf(GtkWidget *, const char *, char *, GtkSignalFunc, gpointer, guint, guint, char *);
-
 #endif /* _UI_H_ */
